# TODOs

- [ ] add [bigdecimal](https://docs.rs/bigdecimal/0.4.1/bigdecimal/) and use it instead of f64s. then return it into python.
- [x] add riemann sum operator
- [x] add modulo
- [ ] add examples to README.md
- [ ] add redimentary limit calculations
